==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d1/d9b/structPool.js <==
var structPool =
[
    [ "AllocCache", "d9/d01/structPool_1_1AllocCache.html", "d9/d01/structPool_1_1AllocCache" ],
    [ "PoolItem", "de/d35/structPool_1_1PoolItem.html", "de/d35/structPool_1_1PoolItem" ],
    [ "Pool", "d1/d9b/structPool.html#a9811fb3f2f2dd76379b5a9b097b04736", null ],
    [ "AllocateItem", "d1/d9b/structPool.html#a0ef484e2a20c069e3e46d18485e54f57", null ],
    [ "assert_compile", "d1/d9b/structPool.html#a101874280c13f21822d418e478d03d28", null ],
    [ "CanAllocate", "d1/d9b/structPool.html#aa8a7f5b08e35beb0832b08d59a54b36c", null ],
    [ "CleanPool", "d1/d9b/structPool.html#a0554f67e30769acd3380051cbf8f2a59", null ],
    [ "FindFirstFree", "d1/d9b/structPool.html#ab79959ca0b5906cd8800b38ef602efb4", null ],
    [ "FreeItem", "d1/d9b/structPool.html#a5d0135f73e1cc799170588bf3b7e64e7", null ],
    [ "Get", "d1/d9b/structPool.html#ae6e3ee94b90c952c02a1cedaf23872aa", null ],
    [ "GetNew", "d1/d9b/structPool.html#adaccc757301692442f850414bdf77d5f", null ],
    [ "GetNew", "d1/d9b/structPool.html#ae26c9b5d2dea49a4c3506705f8d036de", null ],
    [ "IsValidID", "d1/d9b/structPool.html#ab505034b0261c52de0652bd3fb818250", null ],
    [ "ResizeFor", "d1/d9b/structPool.html#a081d7bdb765e43695e625cd588196f26", null ],
    [ "alloc_cache", "d1/d9b/structPool.html#aa7ed966000a48f413916ff401657c519", null ],
    [ "cleaning", "d1/d9b/structPool.html#a95e18a841988066d756a944d1dc9145a", null ],
    [ "data", "d1/d9b/structPool.html#a15f6c4868cf9836a646d498f1a9ef58a", null ],
    [ "first_free", "d1/d9b/structPool.html#a1864a7dd9d1681f342ceea7a45ab38e9", null ],
    [ "first_unused", "d1/d9b/structPool.html#a60f8111b49d106205903d9661277ae9d", null ],
    [ "items", "d1/d9b/structPool.html#a9a7fc46627481a382a697232817f4f69", null ],
    [ "MAX_SIZE", "d1/d9b/structPool.html#a1d2b312d664b7f1514eeadafcb6acd15", null ],
    [ "name", "d1/d9b/structPool.html#a3b2e1e17aded8160eab6dc2b4414e3d6", null ],
    [ "NO_FREE_ITEM", "d1/d9b/structPool.html#ab68097577be8be17c7ef10cb92fd5126", null ],
    [ "size", "d1/d9b/structPool.html#a61d9c1414894f786452f7906dca7bd7b", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d1/d9b/structPool.js <==
var structPool =
[
    [ "AllocCache", "d9/d01/structPool_1_1AllocCache.html", "d9/d01/structPool_1_1AllocCache" ],
    [ "IterateWrapper", "de/d19/structPool_1_1IterateWrapper.html", "de/d19/structPool_1_1IterateWrapper" ],
    [ "IterateWrapperFiltered", "dd/d05/structPool_1_1IterateWrapperFiltered.html", "dd/d05/structPool_1_1IterateWrapperFiltered" ],
    [ "PoolItem", "de/d35/structPool_1_1PoolItem.html", "de/d35/structPool_1_1PoolItem" ],
    [ "PoolIterator", "d8/d37/structPool_1_1PoolIterator.html", "d8/d37/structPool_1_1PoolIterator" ],
    [ "PoolIteratorFiltered", "de/dd2/structPool_1_1PoolIteratorFiltered.html", "de/dd2/structPool_1_1PoolIteratorFiltered" ],
    [ "Pool", "d1/d9b/structPool.html#a9811fb3f2f2dd76379b5a9b097b04736", null ],
    [ "AllocateItem", "d1/d9b/structPool.html#a0ef484e2a20c069e3e46d18485e54f57", null ],
    [ "CanAllocate", "d1/d9b/structPool.html#aa8a7f5b08e35beb0832b08d59a54b36c", null ],
    [ "CleanPool", "d1/d9b/structPool.html#a0554f67e30769acd3380051cbf8f2a59", null ],
    [ "FindFirstFree", "d1/d9b/structPool.html#ab79959ca0b5906cd8800b38ef602efb4", null ],
    [ "FreeItem", "d1/d9b/structPool.html#a5d0135f73e1cc799170588bf3b7e64e7", null ],
    [ "Get", "d1/d9b/structPool.html#ae6e3ee94b90c952c02a1cedaf23872aa", null ],
    [ "GetNew", "d1/d9b/structPool.html#adaccc757301692442f850414bdf77d5f", null ],
    [ "GetNew", "d1/d9b/structPool.html#ae26c9b5d2dea49a4c3506705f8d036de", null ],
    [ "IsValidID", "d1/d9b/structPool.html#ab505034b0261c52de0652bd3fb818250", null ],
    [ "ResizeFor", "d1/d9b/structPool.html#a081d7bdb765e43695e625cd588196f26", null ],
    [ "alloc_cache", "d1/d9b/structPool.html#aa7ed966000a48f413916ff401657c519", null ],
    [ "cleaning", "d1/d9b/structPool.html#a95e18a841988066d756a944d1dc9145a", null ],
    [ "data", "d1/d9b/structPool.html#a15f6c4868cf9836a646d498f1a9ef58a", null ],
    [ "first_free", "d1/d9b/structPool.html#a1864a7dd9d1681f342ceea7a45ab38e9", null ],
    [ "first_unused", "d1/d9b/structPool.html#a60f8111b49d106205903d9661277ae9d", null ],
    [ "items", "d1/d9b/structPool.html#a9a7fc46627481a382a697232817f4f69", null ],
    [ "MAX_SIZE", "d1/d9b/structPool.html#a1d2b312d664b7f1514eeadafcb6acd15", null ],
    [ "name", "d1/d9b/structPool.html#a3b2e1e17aded8160eab6dc2b4414e3d6", null ],
    [ "NO_FREE_ITEM", "d1/d9b/structPool.html#ab68097577be8be17c7ef10cb92fd5126", null ],
    [ "size", "d1/d9b/structPool.html#a61d9c1414894f786452f7906dca7bd7b", null ]
];
